# ****************************************************************************
# E.S.O. - VLT project
#
# "@(#) $Id: pecs.sh,v 1.40 2005/10/26 07:58:51 vltsccm Exp $"
#
# who       when        what
# --------  ----------  ----------------------------------------------
#
# psivera   15/03/01  implemented SPR20000569
# rschmutz  28/03/01  PECS_CONFIG_ROOTS introduced.
# rschmutz  28/03/01  fixed retrieval of multiple tuning files.
# rschmutz  30/03/01  accept $3=onlyconfigroots argument.
# rschmutz  13/05/01  do not complain if a PECS_CONFIG_ROOT does not exist
#                     (e.g. if INTROOT is defined but does not exist).
# psivera   31/05/01  merged with branch 1.22.1.2
# wpirani   07/09/05  added RC keyword
#
#************************************************************************

get_tuning_files()
{
    typeset SCOPE_APPS SCOPE_HOST SCOPE_TYPE TUNING_FILES TUNING_FILE BASE_DIRS BASE_DIR SPECIFIER_LIST SPECIFIER RAISE_ERROR

    SCOPE_APPS=$1
    SCOPE_TYPE=$2

    debug 100 "get_tuning_files: sof (appscope=$SCOPE_APPS, typescope=$SCOPE_TYPE)"

    #  Sanity check the provided scopes.
    case "$SCOPE_TYPE" in
        env|ali|xrdb|wmrc) : ;;
        *)                 internal "get_tuning_files: invalid type scope ($SCOPE_TYPE)" ;;
    esac
    case "$SCOPE_APPS" in
        apps|misc)         : ;;
        *)                 internal "get_tuning_files: invalid apps scope ($SCOPE_APPS)" ;;
    esac
  
    TUNING_FILES=
    if [ "X$3" = Xonlyconfigroots ]; then
	SPECIFIER_LIST=configroots
    else
	SPECIFIER_LIST="applicationwriter systemadministrator configroots user"
    fi
    for SPECIFIER in $SPECIFIER_LIST ; do
	RAISE_ERROR=1
        case $SPECIFIER in
            applicationwriter)   BASE_DIRS=$PECS_ROOTDIR/releases/$PECS_RELEASE/etc/applications ;;
            systemadministrator) BASE_DIRS=$PECS_ROOTDIR/releases/$PECS_RELEASE/etc/locality ;;
            configroots)         if [ "X$PECS_CONFIG_ROOTS" != X ]; then
                                     BASE_DIRS=$PECS_CONFIG_ROOTS
				     RAISE_ERROR=0
				     debug 100 "get_tuning_files: configroots - before (PECS_CONFIG_ROOTS=$PECS_CONFIG_ROOTS)"
                                 else
                                     #  Don't bother falling through to checks for files there
				     debug 100 "get_tuning_files: configroots - skipped (PECS_CONFIG_ROOTS=$PECS_CONFIG_ROOTS)"
                                     continue
                                 fi ;;
            user)                BASE_DIRS=$PERSONAL_CONFIG_DIR ;;
        esac

        if [ $SPECIFIER = applicationwriter ]; then

            #  'env' files contributed by an application are not loaded at the same time as all the
            #  other stuff. This is because of the way they come in two parts: unsetting and deriving.
            #  Actually, the order environment variables are set is as follows:
            #
            #  1) Each application's env contributor script is called in 'unset' mode
            #  2) this function is called to load the settings from the S/A, the user and the introot
            #  3) Each application's env contributor script is called in 'derive' mode
            # 
            #  For all other contributions made by the application (aliases, X resources, GUI menues),
            #  it happens here in the normal way.

            debug 100 "get_tuning_files: application-writer - before (TUNING_FILES=$TUNING_FILES)"
            [ $SCOPE_TYPE != env ] && TUNING_FILES="$TUNING_FILES `/bin/ls $BASE_DIRS/*.$SCOPE_TYPE 2>/dev/null`"
            debug 100 "get_tuning_files: application-writer - after (TUNING_FILES=$TUNING_FILES)"

        else

            debug 100 "get_tuning_files: $SPECIFIER - before (TUNING_FILES=$TUNING_FILES)"
	    for BASE_DIR in $BASE_DIRS; do
		if [ ! -d $BASE_DIR ]; then
		    if [ $RAISE_ERROR = 1 ]; then
		        error "can't find tuning files directory ($BASE_DIR)."
		    fi
                    continue
                fi
                for SCOPE_HOST in all $UNAMEN; do
                    TUNING_FILES="$TUNING_FILES `/bin/ls $BASE_DIR/*$SCOPE_APPS-$SCOPE_HOST.$SCOPE_TYPE 2>/dev/null`"
                done
                debug 100 "get_tuning_files: $SPECIFIER - after (TUNING_FILES=$TUNING_FILES)"
	    done
        fi

    done

    echo $TUNING_FILES
}

SHELL_LIBRARY=$PECS_ROOTDIR/releases/$PECS_RELEASE/lib/utils.sh.shpp
[ ! -f $SHELL_LIBRARY ] && error "can't find shell library ($SHELL_LIBRARY)"
#  To prevent users not being able to log in
ERRORS_CAUSE=return
. $SHELL_LIBRARY
debug 100 "shell library has been loaded by pecs profile"
